@@ -111,13 +111,19 @@ impl SnapshotCmd {
                     ],
                 );
 
-                let snapshots: Vec<_> = snapshots
-                    .into_iter()
-                    .chunk_by(|sn| if self.all { sn.id } else { sn.tree })
-                    .into_iter()
-                    .map(|(_, mut g)| snap_to_table(&g.next().unwrap(), g.count()))
-                    .collect();
-                _ = table.add_rows(snapshots);
+                if self.all {
+                    // Add all snapshots to output table
+                    _ = table.add_rows(snapshots.into_iter().map(|sn| snap_to_table(&sn, 0)));
+                } else {
+                    // Group snapshts by treeid and output into table
+                    _ = table.add_rows(
+                        snapshots
+                            .into_iter()
+                            .chunk_by(|sn| sn.tree)
+                            .into_iter()
+                            .map(|(_, mut g)| snap_to_table(&g.next().unwrap(), g.count())),
+                    );
+                }
                 println!("{table}");
             }
             println!("{count} snapshot(s)");
@@ -164,8 +170,10 @@ pub fn snap_to_table(sn: &SnapshotFile, count: usize) -> [String; 9] {
 pub fn fill_table(snap: &SnapshotFile, mut add_entry: impl FnMut(&str, String)) {
     add_entry("Snapshot", snap.id.to_hex().to_string());
     // note that if original was not set, it is set to snap.id by the load process
-    if snap.original != Some(snap.id) {
-        add_entry("Original ID", snap.original.unwrap().to_hex().to_string());
+    if let Some(original) = snap.original {
+        if original != snap.id {
+            add_entry("Original ID", original.to_hex().to_string());
+        }
     }
     add_entry("Time", snap.time.format("%Y-%m-%d %H:%M:%S").to_string());
     add_entry("Generated by", snap.program_version.clone());
